# BillingPeriod

Billing frequency of the charge. The value of this field controls the duration of each billing period.  Allows billing period to be overridden on the rate plan charge.  If the value of this field is `Specific_Months` or `Specific_Weeks`, use the `specificBillingPeriod` field to specify the duration of each billing period. 

## Enum

* `MONTH` (value: `'Month'`)

* `QUARTER` (value: `'Quarter'`)

* `SEMI_ANNUAL` (value: `'Semi_Annual'`)

* `ANNUAL` (value: `'Annual'`)

* `EIGHTEEN_MONTHS` (value: `'Eighteen_Months'`)

* `TWO_YEARS` (value: `'Two_Years'`)

* `THREE_YEARS` (value: `'Three_Years'`)

* `FIVE_YEARS` (value: `'Five_Years'`)

* `SPECIFIC_MONTHS` (value: `'Specific_Months'`)

* `SUBSCRIPTION_TERM` (value: `'Subscription_Term'`)

* `WEEK` (value: `'Week'`)

* `SPECIFIC_WEEKS` (value: `'Specific_Weeks'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


